guarneri.instrument.Instrument
==============================

.. currentmodule:: guarneri.instrument

.. autoclass:: Instrument

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Instrument.__init__
      ~Instrument.connect
      ~Instrument.load
      ~Instrument.make_device
      ~Instrument.make_devices
      ~Instrument.parse_config
      ~Instrument.parse_toml_file
      ~Instrument.parse_yaml_file
      ~Instrument.validate_params
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Instrument.devices
   
   